@@ -2,6 +2,10 @@
 
 这个是测试内容变化后。自动重启脚本
 """
+import time
 from tests.pac1.m1 import show
 
-show(61)
+
+while 1:
+    time.sleep(5)
+    show(63)
